# RecordV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**orcid_identifier** | [**OrcidIdentifierV30Rc1**](OrcidIdentifierV30Rc1.md) |  | [optional] 
**preferences** | [**PreferencesV30Rc1**](PreferencesV30Rc1.md) |  | [optional] 
**history** | [**HistoryV30Rc1**](HistoryV30Rc1.md) |  | [optional] 
**person** | [**PersonV30Rc1**](PersonV30Rc1.md) |  | [optional] 
**activities_summary** | [**ActivitiesSummaryV30Rc1**](ActivitiesSummaryV30Rc1.md) |  | [optional] 
**path** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

